@@ -2,7 +2,7 @@ package DTOne::Crypt;
 
 use strict;
 use 5.008_005;
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 require Exporter;
 our @ISA = qw(Exporter);
@@ -20,9 +20,18 @@ use constant SCRYPT_PARALLELISM     => 1;
 use constant SCRYPT_DERIVED_KEY_LEN => 32;
 
 sub encrypt_aes256gcm {
-    my $plaintext  = shift or croak "plaintext data required";
+    my $plaintext  = shift;
     my $master_key = shift or croak "master key required";
 
+    unless (defined $plaintext) {
+        croak "plaintext data required";
+    }
+
+    $master_key = decode_base64($master_key);
+    unless (length($master_key) == 32) {
+        croak "invalid master key length";
+    }
+
     my $iv   = random_bytes(12);
     my $salt = random_bytes(16);
     my $key  = scrypt_raw(
@@ -49,8 +58,12 @@ sub decrypt_aes256gcm {
     my $encrypted  = shift or croak "encrypted data required";
     my $master_key = shift or croak "master key required";
 
-    $encrypted = decode_base64($encrypted);
+    $master_key = decode_base64($master_key);
+    unless (length($master_key) == 32) {
+        croak "invalid master key length";
+    }
 
+    $encrypted = decode_base64($encrypted);
     my ($salt, $iv, $tag, $ciphertext) = unpack('a16 a12 a16 a*', $encrypted);
     my $key = scrypt_raw(
         $master_key,
@@ -113,6 +126,10 @@ and tag back to its original plaintext value.
 
 =head1 CAVEATS
 
+=head2 Key Length
+
+Master key is expected to be exactly 256 bits in length, encoded in base64.
+
 =head2 Performance
 
 Random byte generation on Linux might run slow over time unless L<haveged(8)>
